==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/codedeploy/kotlin/inputs/DeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRouteArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.codedeploy.kotlin.inputs

import com.pulumi.aws.codedeploy.inputs.DeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRouteArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property listenerArns List of Amazon Resource Names (ARNs) of the load balancer listeners.
 */
public data class DeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRouteArgs(
    public val listenerArns: Output<List<String>>,
) :
    ConvertibleToJava<com.pulumi.aws.codedeploy.inputs.DeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRouteArgs> {
    override fun toJava():
        com.pulumi.aws.codedeploy.inputs.DeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRouteArgs =
        com.pulumi.aws.codedeploy.inputs.DeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRouteArgs.builder()
            .listenerArns(listenerArns.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [DeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRouteArgs].
 */
@PulumiTagMarker
public class DeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRouteArgsBuilder internal
constructor() {
    private var listenerArns: Output<List<String>>? = null

    /**
     * @param value List of Amazon Resource Names (ARNs) of the load balancer listeners.
     */
    @JvmName("trtqwexyssrsnmci")
    public suspend fun listenerArns(`value`: Output<List<String>>) {
        this.listenerArns = value
    }

    @JvmName("ccntwyuxeffeiqmo")
    public suspend fun listenerArns(vararg values: Output<String>) {
        this.listenerArns = Output.all(values.asList())
    }

    /**
     * @param values List of Amazon Resource Names (ARNs) of the load balancer listeners.
     */
    @JvmName("xxlpxmnqpjkafoqa")
    public suspend fun listenerArns(values: List<Output<String>>) {
        this.listenerArns = Output.all(values)
    }

    /**
     * @param value List of Amazon Resource Names (ARNs) of the load balancer listeners.
     */
    @JvmName("rovaadosgsrevwtg")
    public suspend fun listenerArns(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.listenerArns = mapped
    }

    /**
     * @param values List of Amazon Resource Names (ARNs) of the load balancer listeners.
     */
    @JvmName("kfgurmulrbbgldnv")
    public suspend fun listenerArns(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.listenerArns = mapped
    }

    internal fun build(): DeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRouteArgs =
        DeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRouteArgs(
            listenerArns = listenerArns ?: throw PulumiNullFieldException("listenerArns"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/codedeploy/kotlin/inputs/DeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRouteArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.codedeploy.kotlin.inputs

import com.pulumi.aws.codedeploy.inputs.DeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRouteArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property listenerArns List of Amazon Resource Names (ARNs) of the load balancer listeners.
 */
public data class DeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRouteArgs(
    public val listenerArns: Output<List<String>>,
) :
    ConvertibleToJava<com.pulumi.aws.codedeploy.inputs.DeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRouteArgs> {
    override fun toJava(): com.pulumi.aws.codedeploy.inputs.DeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRouteArgs =
        com.pulumi.aws.codedeploy.inputs.DeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRouteArgs.builder()
            .listenerArns(listenerArns.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [DeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRouteArgs].
 */
@PulumiTagMarker
public class DeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRouteArgsBuilder internal constructor() {
    private var listenerArns: Output<List<String>>? = null

    /**
     * @param value List of Amazon Resource Names (ARNs) of the load balancer listeners.
     */
    @JvmName("hxnmckcmuwxnqwlm")
    public suspend fun listenerArns(`value`: Output<List<String>>) {
        this.listenerArns = value
    }

    @JvmName("lcdoixuxiewvgcun")
    public suspend fun listenerArns(vararg values: Output<String>) {
        this.listenerArns = Output.all(values.asList())
    }

    /**
     * @param values List of Amazon Resource Names (ARNs) of the load balancer listeners.
     */
    @JvmName("kshwaqilpdljqoeu")
    public suspend fun listenerArns(values: List<Output<String>>) {
        this.listenerArns = Output.all(values)
    }

    /**
     * @param value List of Amazon Resource Names (ARNs) of the load balancer listeners.
     */
    @JvmName("efysbyewssubyjsn")
    public suspend fun listenerArns(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.listenerArns = mapped
    }

    /**
     * @param values List of Amazon Resource Names (ARNs) of the load balancer listeners.
     */
    @JvmName("rmjhiajgkbjkfkgh")
    public suspend fun listenerArns(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.listenerArns = mapped
    }

    internal fun build(): DeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRouteArgs =
        DeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRouteArgs(
            listenerArns = listenerArns ?: throw PulumiNullFieldException("listenerArns"),
        )
}
